==> nextcloud-app-mail-1.1.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/ka_GE.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "ფოსტა",
    "Auto detect failed. Please use manual mode." : "ავტო-აღმოჩენა ვერ მოხერხდა. გთხოვთ სცადოთ ხელით.",
    "Updating account failed: " : "ანგარიშის განახლება ვერ მოხერხდა:",
    "Creating account failed: " : "ანგარიშების შექმნა ვერ მოხერხდა:",
    "Name" : "სახელი",
    "Mail Address" : "ფოსტის მისამართი",
    "Password" : "პაროლი",
    "IMAP Host" : "IMAP ჰოსტი",
    "None" : "არც ერთი",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP პორტი",
    "IMAP User" : "IMAP მომხმარებელი",
    "IMAP Password" : "IMAP პაროლი",
    "SMTP Host" : "SMTP ჰოსტი",
    "SMTP Port" : "SMTP პორტი",
    "SMTP User" : "SMTP მომხმარებელი",
    "SMTP Password" : "SMTP პაროლი",
    "Save" : "შენახვა",
    "Connect" : "დაკავშირება",
    "Add mail account" : "საფოსტო ანგარიშის დამატება",
    "Use Gravatar and favicon avatars" : "მოიხმარეთ Gravatar და favicon ავატარები",
    "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
    "Select account" : "აირჩიეთ ანგარიში",
    "Subject" : "სათაური",
    "Upload attachment" : "დანართის ატვირთვა",
    "Add attachment from Files" : "დანართის დამატება ფაილებიდან",
    "Sending …" : "იგზავნება …",
    "Go back" : "უკან დაბრუნება",
    "Retry" : "ვცადოთ ახლიდან",
    "Message sent!" : "წერილი გაგზავნილია!",
    "Send" : "გაგზავნა",
    "Choose a file to add as attachment" : "დანართად დასამატებლად აირჩიეთ ფაილი",
    "Mark read" : "მონიშნეთ წაკითხულად",
    "Delete" : "გაუქმება",
    "Reply" : "პასუხი",
    "Forward" : "წინ",
    "Could not load your message" : "თქვენი წერილის ჩატვირთვა ვერ მოხერხდა",
    "Import into calendar" : "იმპორტი კალენდარში",
    "Download attachment" : "დანართის გადმოწერა",
    "Save to Files" : "შენახვა ფაილებში",
    "Choose a folder to store the attachment in" : "გთხოვთ აირჩიოთ დირექტორია, სადაც მოთავსდება დანართი",
    "Save all to Files" : "ყველაფრის ფაილებში შენახვა",
    "The images have been blocked to protect your privacy." : "სურათები თქვენი კონფიდენციალურობის დასაცავად დაიბლოკა",
    "New message" : "ახალი წერილი",
    "Settings" : "პარამეტრები",
    "Add folder" : "Add folder",
    "Delete account" : "ანგარიშის გაუქმება",
    "Show all folders" : "ყველა დირექტორიის ჩვენება",
    "Collapse folders" : "დირექტორიების კოლაფსი",
    "Mark all as read" : "ყველას წაკითხულად მონიშვნა",
    "Signature" : "ხელმოწერა",
    "General" : "ზოგადი",
    "User" : "მომხმარებელი",
    "Host" : "ჰოსტი",
    "Port" : "პორტი",
    "Speed up your Mail experience with these quick shortcuts." : "მოიხმარეთ ეს კომბინაციები ფოსტასთან უფრო სწრაფად სამუშაოდ.",
    "Compose new message" : "ახალი წერილის შედგენა",
    "Newer message" : "უფრო ახალი წერილი",
    "Older message" : "ძველი წერილი",
    "Toggle star" : "ვარსკლავის გადართვა",
    "Toggle unread" : "წაუკითხავის გადართვა",
    "Search" : "ძიება",
    "Refresh" : "განახლება",
    "Connect your mail account" : "დააკავშირეთ თქვენი ელ-ფოსტის ანგარიში",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n ახალი წერილი\n{from}-ისგან","%n ახალი წერილი\n{from}-ისგან"],
    "Nextcloud Mail" : "Nextcloud ფოსტა",
    "Could not load {tag}{name}{endtag}" : "{tag}{name}{endtag} ვერ ჩაიტვირთა",
    "There was a problem loading {tag}{name}{endtag}" : "{tag}{name}{endtag}-ის ჩატვირთვისას მოხდა შეცდომა",
    "Could not load the desired message" : "სასურველი წერილის ჩატვირთვა ვერ მოხერხდა",
    "Could not load the message" : "წერილის ჩატვირთვა ვერ მოხერხდა",
    "Error loading message" : "წერილის ჩატვირთვისას წარმოიშვა შეცდომა",
    "Forwarding to %s" : "გადაგზავნილია %s-ზე",
    "Click here if you are not automatically redirected within the next few seconds." : "იმ შემთხვევაში, თუ რამდენიმე წამის განმავლობაში არ მოხდება ავტომატური გადამისამართება დააწკაპუნეთ აქ.",
    "Redirect" : "გადამისამართება",
    "The link leads to %s" : "ბმულს მიყევხართ %s-ისკენ",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "თუ არ გსურთ ესტუმროთ იმ გვერდს, შეგიძლიათ დაუბრუნდეთ <a href=\"%s\">ფოსტას</a>.",
    "Continue to %s" : "%s-ისკენ გაგრძელება"
},
"nplurals=2; plural=(n!=1);");

==> nextcloud-app-mail-3.5.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/ka_GE.js <==
OC.L10N.register(
    "mail",
    {
    "Important" : "აუცილებელი",
    "Work" : "სამსახური",
    "Personal" : "პირადი",
    "Later" : "მოგვიანებით",
    "Mail" : "ფოსტა",
    "Name" : "სახელი",
    "Mail address" : "ფოსტის მისამართი",
    "Password" : "პაროლი",
    "IMAP Host" : "IMAP ჰოსტი",
    "None" : "არც ერთი",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP პორტი",
    "IMAP User" : "IMAP მომხმარებელი",
    "IMAP Password" : "IMAP პაროლი",
    "SMTP Host" : "SMTP ჰოსტი",
    "SMTP Port" : "SMTP პორტი",
    "SMTP User" : "SMTP მომხმარებელი",
    "SMTP Password" : "SMTP პაროლი",
    "Connecting" : "მყარდება კავშირი",
    "Save" : "შენახვა",
    "Connect" : "დაკავშირება",
    "Password required" : "საჭიროა პაროლი",
    "Aliases" : "სხვანაირი სახელი",
    "Signature" : "ხელმოწერა",
    "Go back" : "უკან დაბრუნება",
    "Cancel" : "უარყოფა",
    "Add mail account" : "საფოსტო ანგარიშის დამატება",
    "Use Gravatar and favicon avatars" : "მოიხმარეთ Gravatar და favicon ავატარები",
    "Select account" : "აირჩიეთ ანგარიში",
    "Subject" : "სათაური",
    "Upload attachment" : "დანართის ატვირთვა",
    "Add attachment from Files" : "დანართის დამატება ფაილებიდან",
    "Send" : "გაგზავნა",
    "Choose a file to add as attachment" : "დანართად დასამატებლად აირჩიეთ ფაილი",
    "Confirm" : "დადასტურება",
    "Unfavorite" : "რჩეულებიდან ამოშლა",
    "Favorite" : "რჩეული",
    "Read" : "წაკითხვა",
    "Select" : "არჩევა",
    "Edit tags" : "შეცვალეთ ტეგები",
    "More actions" : "მეტი ქმედება",
    "Back" : "უკან",
    "Forward" : "წინ",
    "All day" : "მთელი დღე",
    "Create" : "შექმნა",
    "Comment" : "კომენტარი",
    "Accept" : "მიღება",
    "Decline" : "ურაყოფა",
    "Choose" : "აირჩიეთ",
    "Other" : "სხვა",
    "Reply" : "პასუხი",
    "Import into calendar" : "იმპორტი კალენდარში",
    "Download attachment" : "დანართის გადმოწერა",
    "Save to Files" : "შენახვა ფაილებში",
    "Unnamed" : "უსახელო",
    "Choose a folder to store the attachment in" : "გთხოვთ აირჩიოთ დირექტორია, სადაც მოთავსდება დანართი",
    "Save all to Files" : "ყველაფრის ფაილებში შენახვა",
    "The images have been blocked to protect your privacy." : "სურათები თქვენი კონფიდენციალურობის დასაცავად დაიბლოკა",
    "Move" : "გადატანა",
    "Quota" : "კვოტა",
    "Saving" : "მიმდინარეობს შენახვა",
    "Remove account" : "ანგარიშის გაუქმება",
    "Mark all as read" : "ყველას წაკითხულად მონიშვნა",
    "Clear cache" : "კეშის გასუფთავება",
    "New message" : "ახალი წერილი",
    "Refresh" : "განახლება",
    "Retry" : "ვცადოთ ახლიდან",
    "Sending …" : "იგზავნება …",
    "Message" : "წერილი",
    "Delete" : "გაუქმება",
    "Copy to clipboard" : "კოპირება ბუფერში",
    "Add" : "დამატება",
    "Close" : "დახურვა",
    "Tags" : "ტეგები",
    "Select tags" : "აირჩიეთ ტეგები",
    "Clear" : "გასუფთავება",
    "Search" : "ძიება",
    "Date" : "თარიღი",
    "Disabled" : "არაა მოქმედი",
    "Enabled" : "მოქმედია",
    "Custom" : "ინდივიდუალური",
    "Add tag" : "ტეგის დამატება",
    "Mark as unread" : "წაუკითხავად მონიშვნა",
    "Mark as read" : "წაკითხულად მონიშვნა",
    "Remove" : "წაშლა",
    "Reset" : "საწყის მდოგმარეობაში დაბრუნება",
    "Client ID" : "კლიენტის ID",
    "Client secret" : "კლიენტის საიდუმლო",
    "General" : "ზოგადი",
    "User" : "მომხმარებელი",
    "Host" : "ჰოსტი",
    "Port" : "პორტი",
    "Valid until" : "ვარგისია",
    "Certificate" : "სერტიფიკატი",
    "Submit" : "გაგზავნა",
    "Keyboard shortcut" : "კლავიატურის კომბინაცია",
    "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
    "Speed up your Mail experience with these quick shortcuts." : "მოიხმარეთ ეს კომბინაციები ფოსტასთან უფრო სწრაფად სამუშაოდ.",
    "Compose new message" : "ახალი წერილის შედგენა",
    "Newer message" : "უფრო ახალი წერილი",
    "Older message" : "ძველი წერილი",
    "Toggle star" : "ვარსკლავის გადართვა",
    "Toggle unread" : "წაუკითხავის გადართვა",
    "Archive" : "არქივი",
    "Connect your mail account" : "დააკავშირეთ თქვენი ელ-ფოსტის ანგარიში",
    "All" : "ყველა",
    "Drafts" : "მონახაზები",
    "Favorites" : "რჩეულები",
    "All inboxes" : "ყველა ინბოქსი",
    "Inbox" : "ინბოქსი",
    "Junk" : "უსარგებლო",
    "Sent" : "გაგზავნილი",
    "Trash" : "ნაგავი",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n ახალი წერილი\n{from}-ისგან","%n ახალი წერილი\n{from}-ისგან"],
    "Nextcloud Mail" : "Nextcloud ფოსტა",
    "Message sent" : "წერილი გაგზავნილია",
    "Could not load {tag}{name}{endtag}" : "{tag}{name}{endtag} ვერ ჩაიტვირთა",
    "There was a problem loading {tag}{name}{endtag}" : "{tag}{name}{endtag}-ის ჩატვირთვისას მოხდა შეცდომა",
    "Could not load your message" : "თქვენი წერილის ჩატვირთვა ვერ მოხერხდა",
    "Could not load the desired message" : "სასურველი წერილის ჩატვირთვა ვერ მოხერხდა",
    "Could not load the message" : "წერილის ჩატვირთვა ვერ მოხერხდა",
    "Error loading message" : "წერილის ჩატვირთვისას წარმოიშვა შეცდომა",
    "Forwarding to %s" : "გადაგზავნილია %s-ზე",
    "Click here if you are not automatically redirected within the next few seconds." : "იმ შემთხვევაში, თუ რამდენიმე წამის განმავლობაში არ მოხდება ავტომატური გადამისამართება დააწკაპუნეთ აქ.",
    "Redirect" : "გადამისამართება",
    "The link leads to %s" : "ბმულს მიყევხართ %s-ისკენ",
    "Continue to %s" : "%s-ისკენ გაგრძელება"
},
"nplurals=2; plural=(n!=1);");
